@@ -3,10 +3,10 @@ import re
 from functools import cached_property
 
 from google.protobuf.json_format import ParseDict, MessageToDict  # noqa
-from google.protobuf.message import Message # noqa
+from google.protobuf.message import Message  # noqa
 
-from mgo_serializer.fields import BaseField, Empty, set_value
 from mgo_serializer.exceptions import ValidationError
+from mgo_serializer.fields import BaseField, Empty, set_value
 from mgo_serializer.helpers import BindingDict, ReturnList, ReturnDict, NestedBoundField, BoundField
 from mgo_serializer.meta import SerializerMetaclass
 
@@ -51,8 +51,6 @@ class BaseSerializer(BaseField):
             self.instance = proto_to_dict(self.instance)
         elif isinstance(self.instance, list) and any(isinstance(item, Message) for item in self.instance):
             self.instance = [proto_to_dict(item) for item in self.instance]
-        else:
-            self.instance = copy.deepcopy(self.instance)
 
         if data is not Empty:
             if isinstance(data, list) and any(isinstance(item, Message) for item in data):
@@ -101,6 +99,37 @@ class BaseSerializer(BaseField):
     def to_protobuf(self, data):
         raise NotImplementedError('.to_protobuf() must be implemented.')
 
+    def create(self, validated_data):
+        raise NotImplementedError('.create() must be implemented.')
+
+    def update(self, instance, validated_data):
+        raise NotImplementedError('.update() must be implemented.')
+
+    def save(self, **kwargs):
+        assert hasattr(self, '_errors'), (
+            'You must call `.is_valid()` before calling `.save()`.'
+        )
+
+        assert not self.errors, (
+            'You cannot call `.save()` on a serializer with invalid data.'
+        )
+
+        validated_data = {**self.validated_data, **kwargs}
+
+        primary_keys = [
+            field.field_name for field in self.fields.values()
+            if field.primary_key and validated_data[field.field_name] is not None
+        ]
+
+        # check if primary key is provided
+        if not primary_keys:
+            self.instance = self.create(validated_data)
+        else:
+            primary_key_values = {key: validated_data[key] for key in primary_keys}
+            self.instance = self.update(primary_key_values, validated_data)
+
+        return self.instance
+
     def is_valid(self, raise_exception=False):
         """
         Validates the data.
@@ -170,7 +199,6 @@ class BaseSerializer(BaseField):
                 protobuf_list.append(self.to_protobuf(item))
         else:
             return self.to_protobuf(self._protobuf)
-
         return protobuf_list
 
     @property
@@ -228,7 +256,12 @@ class ListSerializer(BaseSerializer):
         return [self.child.to_representation(item) for item in data]
 
     def to_protobuf(self, data):
-        return self.child.to_protobuf(data)
+        return self.child.to_protobuf(
+            self.child.to_representation(data, protobuf=True)
+        )
+
+    def create(self, validated_data):
+        return [self.child.create(data) for data in validated_data]
 
     @staticmethod
     def validate(attrs):
@@ -342,10 +375,12 @@ class Serializer(BaseSerializer, metaclass=SerializerMetaclass):
 
         return ret
 
-    def to_representation(self, instance):
+    def to_representation(self, instance, protobuf=False):
         ret = {}
         fields = self._readable_fields
         for field in fields:
+            if field.db_only:
+                continue
             attribute = field.get_attribute(instance)
             key = field.proto_field if field.proto_field else field.field_name
             if attribute is None:
@@ -371,8 +406,14 @@ class Serializer(BaseSerializer, metaclass=SerializerMetaclass):
             return NestedBoundField(field, value, error)
         return BoundField(field, value, error)
 
-    # Include a backlink to the serializer class on return objects.
-    # Allows renderers such as HTMLFormRenderer to get the full field info.
+    def create(self, validated_data):
+        model_class = self.meta.model
+        return model_class.objects.create(**validated_data)
+
+    def update(self, instance, validated_data):
+        model = self.meta.model.objects.get(id=instance['id'])
+        model.update(**validated_data)
+        return model
 
     @property
     def data(self):
